@@ -6,8 +6,6 @@ function _aws_cdk_aws_location_CfnGeofenceCollectionProps(p) {
 }
 function _aws_cdk_aws_location_CfnTrackerProps(p) {
 }
-function _aws_cdk_aws_location_CfnPlaceIndexProps(p) {
-}
 function _aws_cdk_aws_location_CfnMapProps(p) {
     if (p == null)
         return;
@@ -16,14 +14,16 @@ function _aws_cdk_aws_location_CfnMapProps(p) {
         _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p.configuration);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_location_CfnPlaceIndexProps(p) {
+}
 function _aws_cdk_aws_location_CfnGeofenceCollection(p) {
 }
 function _aws_cdk_aws_location_CfnRouteCalculator(p) {
 }
-function _aws_cdk_aws_location_CfnTracker(p) {
-}
 function _aws_cdk_aws_location_CfnTrackerConsumer(p) {
 }
+function _aws_cdk_aws_location_CfnTracker(p) {
+}
 function _aws_cdk_aws_location_CfnMap(p) {
 }
 function _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p) {
@@ -47,5 +47,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_location_CfnTrackerConsumerProps, _aws_cdk_aws_location_CfnRouteCalculatorProps, _aws_cdk_aws_location_CfnGeofenceCollectionProps, _aws_cdk_aws_location_CfnTrackerProps, _aws_cdk_aws_location_CfnPlaceIndexProps, _aws_cdk_aws_location_CfnMapProps, _aws_cdk_aws_location_CfnGeofenceCollection, _aws_cdk_aws_location_CfnRouteCalculator, _aws_cdk_aws_location_CfnTracker, _aws_cdk_aws_location_CfnTrackerConsumer, _aws_cdk_aws_location_CfnMap, _aws_cdk_aws_location_CfnMap_MapConfigurationProperty, _aws_cdk_aws_location_CfnPlaceIndex, _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty };
+module.exports = { print, _aws_cdk_aws_location_CfnTrackerConsumerProps, _aws_cdk_aws_location_CfnRouteCalculatorProps, _aws_cdk_aws_location_CfnGeofenceCollectionProps, _aws_cdk_aws_location_CfnTrackerProps, _aws_cdk_aws_location_CfnMapProps, _aws_cdk_aws_location_CfnPlaceIndexProps, _aws_cdk_aws_location_CfnGeofenceCollection, _aws_cdk_aws_location_CfnRouteCalculator, _aws_cdk_aws_location_CfnTrackerConsumer, _aws_cdk_aws_location_CfnTracker, _aws_cdk_aws_location_CfnMap, _aws_cdk_aws_location_CfnMap_MapConfigurationProperty, _aws_cdk_aws_location_CfnPlaceIndex, _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty };
 module.exports.DeprecationError = DeprecationError;
